@@ -1,7 +1,8 @@
 from .argument import Argument
+from .colorer import Colorer, cformat, cprint
 from .command import Command, command
 from .formatter import Formatter, ManualFormatter
 from .metadata import version
-from .mixin import mixin
+from .mixin import Mixin, mixin
 from .option import Option
-from .parser import Parser, ParseError
+from .parser import Parser, ParseResult, ParseError
