@@ -1,11 +1,12 @@
-from box.functools import Decorator
+from sugarbowl import Function
 
 
-class command(Decorator):
+class command(Function):
 
     # Public
 
     marker = '_clyde_command_command'
+    protocol = 'function'
 
     def __call__(self, function):
         setattr(function, self.marker, True)
