@@ -1,5 +1,5 @@
 from jinja2 import PackageLoader
-from box.functools import cachedproperty
+from sugarbowl import cachedproperty
 from .formatter import Formatter
 
 
