@@ -1,11 +1,12 @@
-from box.functools import Decorator
+from sugarbowl import Function
 
 
-class mixin(Decorator):
+class mixin(Function):
 
     # Public
 
     decorator = '_clyde_mixin_mixin'
+    protocol = 'decorator'
 
     def __init__(self, require=None):
         self.__require = require
