@@ -9,9 +9,9 @@ class ProjectModule(ProjectModule):
     author_email = 'roll@respect31.com'
     copyright = 'Copyright (c) 2014 Respect31 <post@respect31.com>'
     description = 'Clyde is a command line interface designer.'
-    development_requires = ['packgram>=0.23']
-    github_user = 'respect31'
-    install_requires = ['box>=0.44', 'jinja2']
+    development_requires = ['packgram>=0.25']
+    github_user = 'clyde-hub'
+    install_requires = ['sugarbowl', 'jinja2']
     interpreters = ['3.3', '3.4']
     license = 'MIT License'
     name = 'clyde'
@@ -19,4 +19,4 @@ class ProjectModule(ProjectModule):
     pypi_password_secure = 'bjVGVG2Gkj9vm65t0BwVqGRTqi6o2qqOFVCo6X7KCfZdrBdL2u7EaNpDqhj8//ITpn5bZsnPWmLXuZEhhStc/kbJpMOgfciIuSZW6IChTiFnUgwK/F/yndhD7G0D6n6hbQ/mCT7KPaH3omZWspjcNdhyhn/NaWD9mZbhrcmPLN8='
     tests_require = ['nose', 'coverage']
     test_suite = 'nose.collector'
-    version = '0.6.0'
+    version = '0.7.0'
